# Wailer

![Unit Tests](https://github.com/WithAgency/Wailer/actions/workflows/tests.yml/badge.svg)
![Documentation](https://readthedocs.com/projects/with-wailer/badge/?version=latest)

Wailer (WITH Mailer) is an utility that builds on top of Django's emailing
capabilities (and SMS through `django-sms`) in order to provide easy solutions
to common emailing problems.

- Inlining CSS of emails you send
- Have direct-access URLs for those emails
- Manage the localization (even from a server-side task)

## Documentation

[✨ **Documentation is there** ✨](https://with-wailer.readthedocs-hosted.com/en/latest/)
